@@ -95,6 +95,20 @@ void canvas_item_to_bottom(canvas_item_t *item) {
   goo_canvas_item_lower(item, NULL);
 }
 
+void canvas_item_set_zoom_max(canvas_item_t *item, float zoom_max) {
+  gdouble vis_thres = zoom_max;
+  GooCanvasItemVisibility vis 
+    = GOO_CANVAS_ITEM_VISIBLE_ABOVE_THRESHOLD;
+  if (vis_thres < 0) {
+    vis_thres = 0;
+    vis = GOO_CANVAS_ITEM_VISIBLE;
+  }
+  g_object_set(G_OBJECT(item),
+               "visibility", vis,
+               "visibility-threshold", vis_thres,
+               NULL);
+}
+
 void canvas_item_destroy(canvas_item_t *item) {
   goo_canvas_item_remove(item);
 }
