@@ -215,7 +215,10 @@ gboolean diff_is_clean(osm_t *osm, gboolean honor_hidden_flags) {
 }
 
 void diff_save(project_t *project, osm_t *osm) {
-  char *diff_name = g_strdup_printf("%s/%s.diff", project->path, project->name);
+  if(!project) return;
+
+  char *diff_name = 
+  g_strdup_printf("%s/%s.diff", project->path, project->name);
 
   if(diff_is_clean(osm, TRUE)) {
     printf("data set is clean, removing diff if present\n");
@@ -688,6 +691,8 @@ void diff_restore(appdata_t *appdata, project_t *project, osm_t *osm) {
  
   g_free(diff_name);
 
+  xmlFreeDoc(doc);
+  xmlCleanupParser();
 
   /* check for hidden ways and update menu accordingly */
   gboolean something_is_hidden = FALSE;
