@@ -113,17 +113,27 @@ void icon_bar_map_item_selected(appdata_t *appdata,
 /* cause an action to take place or interfere with the action */
 void icon_bar_map_action_idle(appdata_t *appdata, gboolean idle) {
   gint i;
-  GtkWidget *action_widgets[] = {
-    appdata->iconbar->trash,
-    appdata->iconbar->info,
+
+  /* icons that are enabled in idle mode */
+  GtkWidget *action_idle_widgets[] = {
     appdata->iconbar->node_add,
     appdata->iconbar->way_add,
+    NULL
+  };
+
+  /* icons that are disabled in idle mode */
+  GtkWidget *action_disable_widgets[] = {
+    appdata->iconbar->trash,
+    appdata->iconbar->info,
     appdata->iconbar->relation_add,
     NULL
   };
 
-  for(i=0;action_widgets[i];i++) 
-    gtk_widget_set_sensitive(action_widgets[i], idle);
+  for(i=0;action_idle_widgets[i];i++) 
+    gtk_widget_set_sensitive(action_idle_widgets[i], idle);
+
+  for(i=0;action_disable_widgets[i];i++) 
+    gtk_widget_set_sensitive(action_disable_widgets[i], FALSE);
 
   /* special handling for icons that depend on further state */
   if(!idle) {
@@ -179,42 +189,48 @@ GtkWidget *iconbar_new(appdata_t *appdata) {
 
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 
-  GtkWidget *toolbar = gtk_toolbar_new();
-  gtk_toolbar_set_orientation(GTK_TOOLBAR(toolbar), GTK_ORIENTATION_VERTICAL);
-  gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_ICONS);
+  iconbar->toolbar = gtk_toolbar_new();
+  gtk_toolbar_set_orientation(GTK_TOOLBAR(iconbar->toolbar), 
+			      GTK_ORIENTATION_VERTICAL);
+  gtk_toolbar_set_style(GTK_TOOLBAR(iconbar->toolbar), GTK_TOOLBAR_ICONS);
 
   /* -------------------------------------------------------- */
-  iconbar->trash = tool_add(toolbar, appdata, "trash", on_trash_clicked);
+  iconbar->trash = tool_add(iconbar->toolbar, appdata, 
+			    "trash", on_trash_clicked);
 
   /* -------------------------------------------------------- */
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(),-1);
-  iconbar->info = tool_add(toolbar, appdata, "info", on_info_clicked);
+  gtk_toolbar_insert(GTK_TOOLBAR(iconbar->toolbar), 
+		     gtk_separator_tool_item_new(),-1);
+  iconbar->info = tool_add(iconbar->toolbar, appdata, "info", on_info_clicked);
 
   /* -------------------------------------------------------- */
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(),-1);
+  gtk_toolbar_insert(GTK_TOOLBAR(iconbar->toolbar), 
+		     gtk_separator_tool_item_new(),-1);
 
-  iconbar->node_add = tool_add(toolbar, appdata, "node_add", 
+  iconbar->node_add = tool_add(iconbar->toolbar, appdata, "node_add", 
 			       on_node_add_clicked);
 
   /* -------------------------------------------------------- */
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(),-1);
+  gtk_toolbar_insert(GTK_TOOLBAR(iconbar->toolbar), 
+		     gtk_separator_tool_item_new(),-1);
 
-  iconbar->way_add = tool_add(toolbar, appdata, "way_add", 
+  iconbar->way_add = tool_add(iconbar->toolbar, appdata, "way_add", 
 			      on_way_add_clicked);
-  iconbar->way_node_add = tool_add(toolbar, appdata, "way_node_add", 
+  iconbar->way_node_add = tool_add(iconbar->toolbar, appdata, "way_node_add", 
 			      on_way_node_add_clicked);
-  iconbar->way_cut = tool_add(toolbar, appdata, "way_cut", 
+  iconbar->way_cut = tool_add(iconbar->toolbar, appdata, "way_cut", 
 			      on_way_cut_clicked);
-  iconbar->way_reverse = tool_add(toolbar, appdata, "way_reverse", 
+  iconbar->way_reverse = tool_add(iconbar->toolbar, appdata, "way_reverse", 
 			      on_way_reverse_clicked);
 
   /* -------------------------------------------------------- */
-  gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(),-1);
+  gtk_toolbar_insert(GTK_TOOLBAR(iconbar->toolbar), 
+		     gtk_separator_tool_item_new(),-1);
 
-  iconbar->relation_add = tool_add(toolbar, appdata, "relation_add", 
+  iconbar->relation_add = tool_add(iconbar->toolbar, appdata, "relation_add", 
 			      on_relation_add_clicked);
 
-  gtk_box_pack_start(GTK_BOX(vbox), toolbar, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), iconbar->toolbar, TRUE, TRUE, 0);
 
   /* -------------------------------------------------------- */
 
@@ -230,3 +246,8 @@ GtkWidget *iconbar_new(appdata_t *appdata) {
 
   return vbox;
 }
+
+void iconbar_free(iconbar_t *iconbar) {
+  if(iconbar)
+    g_free(iconbar);
+}
