@@ -52,6 +52,7 @@ static void main_project_loaded(appdata_t *appdata) {
 
   /* disable all menu entries related to map */
   gtk_widget_set_sensitive(appdata->track.menu_track, loaded);
+  gtk_widget_set_sensitive(appdata->menu_view, loaded);
   gtk_widget_set_sensitive(appdata->menu_osm, loaded);
   gtk_widget_set_sensitive(appdata->menu_wms, loaded);
   gtk_widget_set_sensitive(appdata->menu_map, loaded);
@@ -96,15 +97,20 @@ cb_menu_about(GtkWidget *window, gpointer data) {
 
   gtk_about_dialog_set_name(about, "OSM2Go");
   gtk_about_dialog_set_version(about, VERSION);
-  gtk_about_dialog_set_copyright(about, 
-	 _("OSM2Go (c) 2008 by\n" 
-	 "Till Harbaum <till@harbaum.org>"));
+  gtk_about_dialog_set_copyright(about, _("Copyright 2008"));
+
+  const gchar *authors[] = {
+    "Till Harbaum <till@harbaum.org>",
+    "Andrew Chadwick",
+    NULL };
+
+  gtk_about_dialog_set_authors(about, authors);
 
   gtk_about_dialog_set_website(about,
        _("http://www.harbaum.org/till/maemo"));
   
   gtk_about_dialog_set_comments(about, 
-       _("Maemo OSM Editor"));
+       _("Mobile OSM Editor"));
 
   gtk_widget_show_all(GTK_WIDGET(about));
   gtk_dialog_run(GTK_DIALOG(about));
@@ -228,6 +234,7 @@ cb_menu_fullscreen(GtkWidget *widget, gpointer data) {
   else
     gtk_window_unfullscreen(GTK_WINDOW(appdata->window));
 }
+#endif
 
 static void 
 cb_menu_zoomin(GtkWidget *widget, appdata_t *appdata) {
@@ -244,7 +251,6 @@ cb_menu_zoomout(GtkWidget *widget, appdata_t *appdata) {
   map_set_zoom(appdata->map, appdata->map->state->zoom/ZOOM_FACTOR_MENU, TRUE);
   printf("zoom is now %f\n", appdata->map->state->zoom);
 }
-#endif
 
 static void 
 cb_menu_track_import(GtkWidget *window, appdata_t *appdata) {
@@ -324,26 +330,6 @@ void menu_create(appdata_t *appdata) {
   GtkWidget *menu, *item, *submenu;
   menu = gtk_menu_new();
 
-#ifdef USE_HILDON
-  item = gtk_menu_item_new_with_label( _("View") );
-  gtk_menu_append(GTK_MENU_SHELL(menu), item);
-  submenu = gtk_menu_new();
-  gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
-  
-  appdata->fullscreen_menu_item = 
-    item = gtk_check_menu_item_new_with_label( _("Fullscreen") );
-  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
-  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_fullscreen), 
-		   appdata);
-
-  item = gtk_menu_item_new_with_label( _("Zoom +" ));
-  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
-  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_zoomin), appdata);
-
-  item = gtk_menu_item_new_with_label( _("Zoom -") );
-  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
-  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_zoomout), appdata);
-#endif
 
   /* -------------------- Project submenu -------------------- */
 
@@ -363,6 +349,32 @@ void menu_create(appdata_t *appdata) {
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_project_close), 
 		   appdata);
 
+  /* --------------- view menu ------------------- */
+
+  gtk_menu_append(GTK_MENU_SHELL(menu), gtk_separator_menu_item_new());
+
+  appdata->menu_view = item = 
+    gtk_menu_item_new_with_label( _("View") );
+  gtk_menu_append(GTK_MENU_SHELL(menu), item);
+  submenu = gtk_menu_new();
+  gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
+  
+#ifdef USE_HILDON
+  appdata->fullscreen_menu_item = 
+    item = gtk_check_menu_item_new_with_label( _("Fullscreen") );
+  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_fullscreen), 
+		   appdata);
+#endif
+
+  item = gtk_menu_item_new_with_label( _("Zoom +" ));
+  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_zoomin), appdata);
+
+  item = gtk_menu_item_new_with_label( _("Zoom -") );
+  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_zoomout), appdata);
+
   /* -------------------- OSM submenu -------------------- */
 
   appdata->menu_osm = item = gtk_menu_item_new_with_label( _("OSM") );
@@ -398,14 +410,14 @@ void menu_create(appdata_t *appdata) {
 		   appdata);
 
   appdata->menu_item_wms_clear = item = 
-    gtk_menu_item_new_with_label( _("Clear...") );
+    gtk_menu_item_new_with_label( _("Clear") );
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
   gtk_widget_set_sensitive(item, FALSE);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_wms_clear), 
 		   appdata);
 
   appdata->menu_item_wms_adjust = item = 
-    gtk_menu_item_new_with_label( _("Adjust...") );
+    gtk_menu_item_new_with_label( _("Adjust") );
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
   gtk_widget_set_sensitive(item, FALSE);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_wms_adjust), 
@@ -687,6 +699,13 @@ int main(int argc, char *argv[]) {
 
   appdata.presets = josm_presets_load();
 
+  /* let gtk do its thing before loading the data, */
+  /* so the user sees something */
+  while(gtk_events_pending()) {
+    putchar('.');
+    gtk_main_iteration();
+  }
+
   /* load project if one is specified in the settings */
   if(appdata.settings->project)
     project_load(&appdata, appdata.settings->project);
