@@ -1027,7 +1027,7 @@ static gboolean map_scroll_event(GtkWidget *widget, GdkEventScroll *event,
 				 gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
 
-  if(!appdata->osm) return TRUE;
+  if(!appdata->osm) return FALSE;
 
   if(event->type == GDK_SCROLL && appdata->map && appdata->map->state) {
     if(event->direction) 
@@ -1477,6 +1477,8 @@ static gboolean map_button_event(GtkWidget *widget, GdkEventButton *event,
   appdata_t *appdata = (appdata_t*)data;
   map_t *map = appdata->map;
 
+  if(!appdata->osm) return FALSE;
+
   if(event->button == 1) {
     gint x = event->x, y = event->y;
 
@@ -1497,6 +1499,8 @@ static gboolean map_motion_notify_event(GtkWidget *widget,
   gint x, y;
   GdkModifierType state;
 
+  if(!appdata->osm) return FALSE;
+
 #ifdef USE_HILDON
   /* reduce update frequency on hildon to keep screen update fluid */
   static guint32 last_time = 0;
@@ -1572,6 +1576,9 @@ static gboolean map_motion_notify_event(GtkWidget *widget,
 }
 
 gboolean map_key_press_event(appdata_t *appdata, GdkEventKey *event) {
+
+  if(!appdata->osm) return FALSE;
+
   /* map needs to be there to handle buttons */
   if(!appdata->map->canvas) 
     return FALSE;
