@@ -202,7 +202,7 @@ void map_edit_way_add_segment(map_t *map, gint x, gint y) {
       map_item_chain_destroy(&map->action.way->map_item_chain);
       
       /* draw current way */
-      map_way_color(map->appdata->potlatch, map->action.way);
+      josm_elemstyles_colorize_way(map->style, map->action.way);
       map_way_draw(map, map->action.way);
     }
   }
@@ -225,7 +225,7 @@ void map_edit_way_add_cancel(map_t *map) {
     chain->node->ways--;
     if(!chain->node->ways && (chain->node->id == ID_ILLEGAL)) {
       printf("      -> freeing temp node\n");
-      osm_node_free(chain->node);
+      osm_node_free(&map->appdata->icon, chain->node);
     }
     g_free(chain);
     chain = next;
@@ -397,7 +397,7 @@ void map_edit_way_node_add_highlight(map_t *map, map_item_t *item,
     gint nx, ny;
     canvas_window2world(map->canvas, x, y, &nx, &ny);
     if(canvas_item_get_segment(item->item, nx, ny) >= 0)
-      map_hl_cursor_draw(map, x, y, FALSE, RADIUS);
+      map_hl_cursor_draw(map, x, y, FALSE, map->style->node.radius);
   }
 }
 
@@ -465,8 +465,10 @@ void map_edit_way_cut_highlight(map_t *map, map_item_t *item, gint x, gint y) {
       gint x0, y0, x1, y1;
       canvas_item_get_segment_pos(item->item, seg, &x0, &y0, &x1, &y1);
       
-      gint width = (item->way->draw_flags & 
-		    OSM_DRAW_FLAG_STROKE)?2*STROKE_WIDTH:3*WAY_WIDTH;
+      gint width = (item->way->draw.flags & 
+		    OSM_DRAW_FLAG_BG)?
+	2*item->way->draw.bg.width:
+	3*item->way->draw.width;
       map_hl_segment_draw(map, width, x0, y0, x1, y1);
     }
   } else if(map_item_is_selected_node(map, item)) {
@@ -476,7 +478,7 @@ void map_edit_way_cut_highlight(map_t *map, map_item_t *item, gint x, gint y) {
     /* cutting a way at its first or last node doesn't make much sense ... */
     if((nfirst != item->node) && (nlast != item->node)) 
       map_hl_cursor_draw(map, item->node->lpos.x, item->node->lpos.y, 
-			 TRUE, 2*RADIUS);
+			 TRUE, 2*map->style->node.radius);
   }
 }
 
@@ -596,12 +598,12 @@ void map_edit_way_cut(map_t *map, gint x, gint y) {
 	       osm_way_number_of_nodes(way));
 	
 	/* draw the updated old way */
-	map_way_color(map->appdata->potlatch, way);
+	josm_elemstyles_colorize_way(map->style, way);
 	map_way_draw(map, way);
 	
 	/* remember that the way needs to be uploaded */
 	way->flags |= OSM_FLAG_DIRTY;
-	}
+      }
       
       if(osm_way_number_of_nodes(new) < 2) {
 	printf("new way has less than 2 nodes, deleting it\n");
@@ -610,8 +612,8 @@ void map_edit_way_cut(map_t *map, gint x, gint y) {
       } else {
 	
 	/* colorize the new way before drawing */
-	map_way_color(map->appdata->potlatch, new);
-	  map_way_draw(map, new);
+	josm_elemstyles_colorize_way(map->style, new);
+	map_way_draw(map, new);
       }
       
       /* put gui into idle state */
@@ -712,7 +714,7 @@ void map_edit_node_move(appdata_t *appdata, map_item_t *map_item,
 
       /* and remove it from the data structures */
       osm_node_remove_from_relation(appdata->osm, touchnode);
-      osm_node_delete(appdata->osm, touchnode, FALSE, TRUE);
+      osm_node_delete(appdata->osm, &appdata->icon, touchnode, FALSE, TRUE);
       
       /* and open dialog to resolve tag collisions if necessary */
       if(conflict)
@@ -892,7 +894,7 @@ void map_edit_node_move(appdata_t *appdata, map_item_t *map_item,
       map_item_chain_destroy(&way->map_item_chain);
 
       /* draw current way */
-      map_way_color(appdata->potlatch, way);
+      josm_elemstyles_colorize_way(map->style, way);
       map_way_draw(map, way);
     }
     
@@ -906,3 +908,21 @@ void map_edit_node_move(appdata_t *appdata, map_item_t *map_item,
   map_highlight_refresh(appdata);
 }
 			  
+/* -------------------------- way_reverse ----------------------- */
+
+/* called from the "reverse" icon */
+void map_edit_way_reverse(appdata_t *appdata) {
+  /* work on local copy since de-selecting destroys the selection */
+  map_item_t item = appdata->map->selected;
+
+  /* deleting the selected item de-selects it ... */
+  map_item_deselect(appdata);
+
+  g_assert(item.type == MAP_TYPE_WAY);
+
+  osm_way_revert(item.way);
+  item.way->flags |= OSM_FLAG_DIRTY;
+
+  map_way_select(appdata, item.way);
+}
+
