@@ -53,13 +53,6 @@ static char *osm_http_message(int id) {
   return NULL;
 }
 
-// http://curl.haxx.se/lxr/source/docs/examples/curlgtk.c
-
-// http://wiki.openstreetmap.org/index.php/OSM_Protocol_Version_0.5
-
-// GET /api/0.5/map?bbox=left,bottom,right,top
-// http://api.openstreetmap.org/api/0.5/map?bbox=11.54,48.14,11.543,48.145
-
 typedef struct {
   GtkWidget *wait_dialog;
   GtkWidget *pbar;
@@ -496,8 +489,9 @@ static void osm_delete_nodes(osm_upload_context_t *context) {
       appendf(&context->log, _("Delete node #%ld "), node->id);
 
       char *url = g_strdup_printf("%s/node/%lu", project->server, node->id);
-      char *cred = g_strdup_printf("%s:%s", project->username, 
-				   project->password);
+      char *cred = g_strdup_printf("%s:%s", 
+				   context->appdata->settings->username, 
+				   context->appdata->settings->password);
 
       if(osm_delete_item(&context->log, url, cred)) {
 	node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
@@ -536,7 +530,7 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
 	printf("uploading node %s from address %p\n", url, xml_str);
 
 	char *cred = g_strdup_printf("%s:%s", 
-				     project->username, project->password);
+				     context->appdata->settings->username, context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
 			   (node->flags & OSM_FLAG_NEW)?&(node->id):NULL)) {
 
@@ -566,7 +560,7 @@ static void osm_delete_ways(osm_upload_context_t *context) {
 
       char *url = g_strdup_printf("%s/way/%lu", project->server, way->id);
       char *cred = g_strdup_printf("%s:%s", 
-				   project->username, project->password);
+				   context->appdata->settings->username, context->appdata->settings->password);
 
       if(osm_delete_item(&context->log, url, cred)) {
 	way->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
@@ -606,7 +600,7 @@ static void osm_upload_ways(osm_upload_context_t *context) {
 	printf("uploading way %s from address %p\n", url, xml_str);
 	
 	char *cred = g_strdup_printf("%s:%s", 
-				     project->username, project->password);
+				     context->appdata->settings->username, context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
 			   (way->flags & OSM_FLAG_NEW)?&(way->id):NULL)) {
 	  way->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
@@ -647,7 +641,7 @@ static void osm_upload_relations(osm_upload_context_t *context) {
 	printf("uploading relation %s from address %p\n", url, xml_str);
 	
 	char *cred = g_strdup_printf("%s:%s", 
-				     project->username, project->password);
+				     context->appdata->settings->username, context->appdata->settings->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, 
 		   (relation->flags & OSM_FLAG_NEW)?&(relation->id):NULL)) {
 	  relation->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
@@ -755,12 +749,12 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   table_attach_label_l(table, _("Username:"), 0, 1, 0, 1);
   GtkWidget *uentry = gtk_entry_new();
   HILDON_ENTRY_NO_AUTOCAP(uentry);
-  gtk_entry_set_text(GTK_ENTRY(uentry), project->username);
+  gtk_entry_set_text(GTK_ENTRY(uentry), appdata->settings->username);
   gtk_table_attach_defaults(GTK_TABLE(table),  uentry, 1, 2, 0, 1);
   table_attach_label_l(table, _("Password:"), 0, 1, 1, 2);
   GtkWidget *pentry = gtk_entry_new();
   HILDON_ENTRY_NO_AUTOCAP(pentry);
-  gtk_entry_set_text(GTK_ENTRY(pentry), project->password);
+  gtk_entry_set_text(GTK_ENTRY(pentry), appdata->settings->password);
   gtk_entry_set_visibility(GTK_ENTRY(pentry), FALSE);
   gtk_table_attach_defaults(GTK_TABLE(table),  pentry, 1, 2, 1, 2);
   gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox), table);
@@ -776,10 +770,15 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   printf("clicked ok\n");
 
   /* retrieve username and password */
-  if(project->username) g_free(project->username);
-  project->username = g_strdup(gtk_entry_get_text(GTK_ENTRY(uentry)));
-  if(project->password) g_free(project->password);
-  project->password = g_strdup(gtk_entry_get_text(GTK_ENTRY(pentry)));
+  if(appdata->settings->username) 
+    g_free(appdata->settings->username);
+  appdata->settings->username = 
+    g_strdup(gtk_entry_get_text(GTK_ENTRY(uentry)));
+
+  if(appdata->settings->password) 
+    g_free(appdata->settings->password);
+  appdata->settings->password = 
+    g_strdup(gtk_entry_get_text(GTK_ENTRY(pentry)));
 
   gtk_widget_destroy(dialog);
   project_save(GTK_WIDGET(appdata->window), project);
@@ -873,10 +872,9 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
 
       /* redraw the entire map by destroying all map items and redrawing them */
       appendf(&context->log, _("Cleaning up ...\n"));
-      track_save(appdata->project, appdata->track.track);
       diff_save(appdata->project, appdata->osm);
-      map_clear(appdata);
-      osm_free(appdata->osm);
+      map_clear(appdata, MAP_LAYER_OBJECTS_ONLY);
+      osm_free(&appdata->icon, appdata->osm);
       
       appendf(&context->log, _("Loading OSM ...\n"));
       appdata->osm = osm_parse(appdata->project->osm);
@@ -884,11 +882,6 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
       diff_restore(appdata, appdata->project, appdata->osm);
       appendf(&context->log, _("Painting ...\n"));
       map_paint(appdata);
-      appendf(&context->log, _("Restoring track ...\n"));
-      appdata->track.track = track_restore(appdata, appdata->project);
-      if(appdata->track.track)
-	map_track_draw(appdata->map, appdata->track.track);
-      wms_load(appdata);
       appendf(&context->log, _("Done!\n"));
     }
   }
