@@ -1068,7 +1068,7 @@ gboolean project_close(appdata_t *appdata) {
   if(appdata->osm)
     diff_save(appdata->project, appdata->osm);
 
-  map_clear(appdata, MAP_LAYER_OBJECTS_ONLY);
+  map_clear(appdata, MAP_LAYER_ALL);
 
   if(appdata->osm) {
     osm_free(&appdata->icon, appdata->osm);
