@@ -27,11 +27,16 @@
 #define BASE_DIR "/media/mmc2/osm2go/"
 #endif
 
+#define DEFAULT_STYLE "mapnik"
+
 typedef struct settings_s {
 
   /* never changed */
   char *base_path;
 
+  /* changed in project.c */
+  char *project;
+
   /* changed in osm_api.c */
   char *server, *username, *password;
 
